@@ -1,6 +1,4 @@
-from fastadmin.app import admin_app
-from fastadmin.models.base import ModelAdmin
+from fastadmin.models.base import InlineModelAdmin, ModelAdmin
 from fastadmin.models.decorators import action, display, register
-from fastadmin.models.orm.tortoise import TortoiseModelAdmin
 from fastadmin.schemas.api import ExportFormat
 from fastadmin.schemas.configuration import WidgetType
