@@ -6,7 +6,7 @@ from uuid import UUID
 
 from fastapi import HTTPException, status
 
-from fastadmin.models.base import BaseModelAdmin
+from fastadmin.models.base import InlineModelAdmin, ModelAdmin
 from fastadmin.models.helpers import get_admin_model
 from fastadmin.schemas.configuration import WidgetType
 from fastadmin.settings import settings
@@ -41,7 +41,7 @@ async def obj_to_dict(obj: Any, with_m2m: bool = True, with_display_fields: bool
     return obj_dict
 
 
-class TortoiseModelAdmin(BaseModelAdmin):
+class TortoiseMixin:
     async def save_model(self, id: UUID | int | None, payload: dict) -> dict | None:
         """This method is used to save orm/db model object.
 
@@ -150,10 +150,10 @@ class TortoiseModelAdmin(BaseModelAdmin):
             qs = qs.order_by(sort_by)
         else:
             if self.ordering:
-                for sort_by in self.ordering:
-                    if sort_by.strip("-") not in fields:
+                for ordering_field in self.ordering:
+                    if ordering_field.strip("-") not in fields:
                         raise HTTPException(
-                            status.HTTP_422_UNPROCESSABLE_ENTITY, detail=f"Sort by {sort_by} is not allowed"
+                            status.HTTP_422_UNPROCESSABLE_ENTITY, detail=f"Sort by {ordering_field} is not allowed"
                         )
                 qs = qs.order_by(*self.ordering)
 
@@ -334,3 +334,11 @@ class TortoiseModelAdmin(BaseModelAdmin):
                     "options": [{"label": k, "value": k} for k in field.get("enum_type") or []],
                 }
         return WidgetType.Input, widget_props
+
+
+class TortoiseModelAdmin(TortoiseMixin, ModelAdmin):
+    pass
+
+
+class TortoiseInlineModelAdmin(TortoiseMixin, InlineModelAdmin):
+    pass
